#!/usr/bin/env python
#-*- coding:utf-8 -*-

def sum(*values):
    s = 0
    for v in values:
        i = int(v)
        s = s + i
    print s

def output():
    print 'https://browser.qq.com/ipad/pc.html'